package cz.moneta.test.dsl.ufo.mwf;

import cz.moneta.test.harness.support.mwf.Parameter;
import cz.moneta.test.harness.support.mwf.MwfRequest;

public interface MWFHK8 extends MwfRequest<MWFHK8, MWFHK8Response> {

    @Parameter(name = "Adresy_OutputAktualniFlag")
    MWFHK8 AdresyOutputAktualniFlag(String AdresyOutputAktualniFlag);
    @Parameter(name = "Adresy_OutputSysIDs")
    MWFHK8 AdresyOutputSysIDs(String AdresyOutputSysIDs);
    @Parameter(name = "BusinessRequestor")
    MWFHK8 BusinessRequestor(String BusinessRequestor);
    @Parameter(name = "BusinessTarget")
    MWFHK8 BusinessTarget(String BusinessTarget);
    @Parameter(name = "CisloDokladu")
    MWFHK8 CisloDokladu(String CisloDokladu);
    @Parameter(name = "CisloKarty")
    MWFHK8 CisloKarty(String CisloKarty);
    @Parameter(name = "CisloSmlouvy")
    MWFHK8 CisloSmlouvy(String CisloSmlouvy);
    @Parameter(name = "CisloUctu")
    MWFHK8 CisloUctu(String CisloUctu);
    @Parameter(name = "DatumNarozeni")
    MWFHK8 DatumNarozeni(java.util.Date DatumNarozeni);
    @Parameter(name = "DokladTyp")
    MWFHK8 DokladTyp(String DokladTyp);
    @Parameter(name = "ICO")
    MWFHK8 Ico(String Ico);
    @Parameter(name = "IDAdresy")
    MWFHK8 IDAdresy(Long IDAdresy);
    @Parameter(name = "IDAdresy_SRCSystem")
    MWFHK8 IDAdresySRCSystem(String IDAdresySRCSystem);
    @Parameter(name = "IDCustomer")
    MWFHK8 IDCustomer(String IDCustomer);
    @Parameter(name = "IDInstanceKlienta")
    MWFHK8 IDInstanceKlienta(Long IDInstanceKlienta);
    @Parameter(name = "IDKonsolidovanehoKlienta")
    MWFHK8 IDKonsolidovanehoKlienta(Long IDKonsolidovanehoKlienta);
    @Parameter(name = "IDUnifikovanehoKlienta")
    MWFHK8 IDUnifikovanehoKlienta(Long IDUnifikovanehoKlienta);
    @Parameter(name = "IDZadosti")
    MWFHK8 IDZadosti(String IDZadosti);
    @Parameter(name = "IDZdrojovehoSystemu")
    MWFHK8 IDZdrojovehoSystemu(String IDZdrojovehoSystemu);
    @Parameter(name = "IDZdrojovehoSystemu_OUTPUT")
    MWFHK8 IDZdrojovehoSystemuOUTPUT(String IDZdrojovehoSystemuOUTPUT);
    @Parameter(name = "Jmeno")
    MWFHK8 Jmeno(String Jmeno);
    @Parameter(name = "KartaRole")
    MWFHK8 KartaRole(String KartaRole);
    @Parameter(name = "MaximalniPocetZaznamu")
    MWFHK8 MaximalniPocetZaznamu(Long MaximalniPocetZaznamu);
    @Parameter(name = "NazevFirmy")
    MWFHK8 NazevFirmy(String NazevFirmy);
    @Parameter(name = "Prijmeni")
    MWFHK8 Prijmeni(String Prijmeni);
    @Parameter(name = "Priznak_BankovniTajemstvi")
    MWFHK8 PriznakBankovniTajemstvi(String PriznakBankovniTajemstvi);
    @Parameter(name = "Priznak_RozsirenyVystup")
    MWFHK8 PriznakRozsirenyVystup(String PriznakRozsirenyVystup);
    @Parameter(name = "RC")
    MWFHK8 Rc(String Rc);
    @Parameter(name = "TypyOsobyFiltr")
    MWFHK8 TypyOsobyFiltr(String TypyOsobyFiltr);
    @Parameter(name = "UcelDotazu")
    MWFHK8 UcelDotazu(String UcelDotazu);
    @Parameter(name = "ZECO")
    MWFHK8 Zeco(String Zeco);
}
